@@ -2,7 +2,8 @@ use 5.006;
 
 package Test::DiagINC;
 # ABSTRACT: List modules and versions loaded if tests fail
-our $VERSION = '0.004'; # VERSION
+
+our $VERSION = '0.006';
 
 # If the tested module did not load strict/warnings we do not want
 # to load them either. On the other hand we would like to know our
@@ -160,7 +161,7 @@ Test::DiagINC - List modules and versions loaded if tests fail
 
 =head1 VERSION
 
-version 0.004
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -261,10 +262,22 @@ L<https://github.com/dagolden/Test-DiagINC>
 
 David Golden <dagolden@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
+
+=for stopwords Peter Rabbitson Roy Ivy III
+
+=over 4
+
+=item *
 
 Peter Rabbitson <ribasushi@cpan.org>
 
+=item *
+
+Roy Ivy III <rivy.dev@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2014 by David Golden.
